@@ -18,7 +18,7 @@ package Class::DBI::Pageset;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our $AUTOLOAD;
 
 use Class::DBI 0.90;
@@ -112,7 +112,7 @@ to search via C<Class::DBI> and grouping results into pages and page sets.
 
 This module is very similar to Tatsuhiko Miyagawa's very nice
 C<Class::DBI::Pager> module, but uses C<Data::Pageset> (or any module that
-inherits from C<Data::Pageset>, such as C<Data::Pageset::HTML>) to create
+inherits from C<Data::Pageset>, such as C<Data::Pageset::Render>) to create
 the pager. C<Data::Pageset> provides a more flexible pager, which is better
 suited to searches that return many pages. This is not necessarily very
 efficient (see C<NOTE> below for more).
@@ -154,10 +154,10 @@ efficient (see C<NOTE> below for more).
   [% END %]
 
 To use one of the modules that inherit from C<Data::Pageset> (such as 
-C<Data::Pageset::HTML>) just include the module name as part of the C<use>
+C<Data::Pageset::Render>) just include the module name as part of the C<use>
 statement.
 
-    use Class::DBI::Pageset qw(Data::Pageset::HTML);
+    use Class::DBI::Pageset qw(Data::Pageset::Render);
     ## Then in your code you can use
     $pager->html( '<a href="index?page=%s">%a</a>' );
 
@@ -221,7 +221,7 @@ return many pages of results, it maybe more prone to inefficiencies than
 C<Class::DBI::Pager>.
 
 I had originally wanted to patch C<Class::DBI::Pager> to use different pagers,
-ie, C<Data::Page>, C<Data::Pageset>, or C<Data::Pageset::HTML>, but the 
+ie, C<Data::Page>, C<Data::Pageset>, or C<Data::Pageset::Render>, but the 
 constructors for C<Data::Page> and C<Data::Pageset> are incompatible and 
 jamming them together didn't seem like a good fix.
 
@@ -239,11 +239,11 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-DBI-Pageset>
 
 =head1 AUTHOR
 
+Mark Grimes E<lt>mgrimes@cpan.orgE<gt>
+
 Most of this code was shamelessly taken from the very nice
 C<Class::DBI::Pager> by Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>.
 
-Mark Grimes E<lt>mgrimes@cpan.orgE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2008 by mgrimes
